@@ -42,7 +42,7 @@ _DULWICH_TYPES = {
 
 class CoreSWHIDParamType(click.ParamType):
     """Click argument that accepts a core SWHID and returns them as
-    :class:`swh.model.swhids.CoreSWHID` instances """
+    :class:`swh.model.swhids.CoreSWHID` instances"""
 
     name = "SWHID"
 
@@ -209,7 +209,10 @@ def identify_object(
     help="reference identifier to be compared with computed one",
 )
 @click.option(
-    "-r", "--recursive", is_flag=True, help="compute SWHID recursively",
+    "-r",
+    "--recursive",
+    is_flag=True,
+    help="compute SWHID recursively",
 )
 @click.argument("objects", nargs=-1, required=True)
 def identify(
@@ -226,30 +229,26 @@ def identify(
 
     For more details about SWHIDs see:
 
-    \b
     https://docs.softwareheritage.org/devel/swh-model/persistent-identifiers.html
 
     Tip: you can pass "-" to identify the content of standard input.
 
-    \b
     Examples::
 
-    \b
       $ swh identify fork.c kmod.c sched/deadline.c
       swh:1:cnt:2e391c754ae730bd2d8520c2ab497c403220c6e3    fork.c
       swh:1:cnt:0277d1216f80ae1adeed84a686ed34c9b2931fc2    kmod.c
       swh:1:cnt:57b939c81bce5d06fa587df8915f05affbe22b82    sched/deadline.c
 
-    \b
       $ swh identify --no-filename /usr/src/linux/kernel/
       swh:1:dir:f9f858a48d663b3809c9e2f336412717496202ab
 
-    \b
       $ git clone --mirror https://forge.softwareheritage.org/source/helloworld.git
-      $ swh identify --type snapshot helloworld.git/
-      swh:1:snp:510aa88bdc517345d258c1fc2babcd0e1f905e93	helloworld.git
 
-    """  # NoQA  # overlong lines in shell examples are fine
+      $ swh identify --type snapshot helloworld.git/
+      swh:1:snp:510aa88bdc517345d258c1fc2babcd0e1f905e93    helloworld.git
+
+    """
     from functools import partial
     import logging
 
