@@ -300,16 +300,20 @@ def extract_regex_objs(
 
     Args:
       root_path (bytes): path to the root directory
-      patterns (list of byte): patterns to match
+      patterns (list of byte): shell patterns to match
 
      Yields:
         an SRE_Pattern object
     """
     absolute_root_path = os.path.abspath(root_path)
     for pattern in patterns:
-        for path in glob.glob(pattern):
-            absolute_path = os.path.abspath(path)
-            if not absolute_path.startswith(absolute_root_path):
+        if os.path.isabs(pattern):
+            pattern = os.path.relpath(pattern, root_path)
+        # python 3.10 has a `root_dir` argument for glob, but not the previous
+        # version. So we adjust the pattern
+        test_pattern = os.path.join(absolute_root_path, pattern)
+        for path in glob.glob(test_pattern):
+            if os.path.isabs(path) and not path.startswith(absolute_root_path):
                 error_msg = (
                     b'The path "' + path + b'" is not a subdirectory or relative '
                     b'to the root directory path: "' + root_path + b'"'
@@ -326,7 +330,7 @@ def ignore_directories_patterns(root_path: bytes, patterns: Iterable[bytes]):
 
     Args:
       root_path (bytes): path of the root directory
-      patterns (list of byte): patterns to ignore
+      patterns (list of bytes): patterns to ignore
 
     Returns:
       a directory filter for :func:`directory_to_objects`
@@ -401,7 +405,7 @@ class Directory(MerkleNode):
     for instance when the client is applying diffs.
     """
 
-    __slots__ = ["__entries"]
+    __slots__ = ["__entries", "__model_object"]
     object_type: Final = "directory"
 
     @classmethod
@@ -447,9 +451,11 @@ class Directory(MerkleNode):
     def __init__(self, data=None):
         super().__init__(data=data)
         self.__entries = None
+        self.__model_object = None
 
     def invalidate_hash(self):
         self.__entries = None
+        self.__model_object = None
         super().invalidate_hash()
 
     @staticmethod
@@ -497,12 +503,37 @@ class Directory(MerkleNode):
         return CoreSWHID(object_type=ObjectType.DIRECTORY, object_id=self.hash)
 
     def compute_hash(self):
-        return model.Directory.from_dict({"entries": self.entries}).id
+        return self.to_model().id
 
     def to_model(self) -> model.Directory:
         """Builds a `model.Directory` object based on this node;
         ignoring its children."""
-        return model.Directory.from_dict(self.get_data())
+        if self.__model_object is None:
+
+            DirectoryEntry = model.DirectoryEntry
+
+            entries = []
+            for name, child in self.items():
+                if child.object_type == "directory":
+                    e = DirectoryEntry(
+                        type="dir",
+                        perms=DentryPerms.directory,
+                        target=child.hash,
+                        name=name,
+                    )
+                elif child.object_type == "content":
+                    e = DirectoryEntry(
+                        type="file",
+                        perms=child.data["perms"],
+                        target=child.hash,
+                        name=name,
+                    )
+                else:
+                    raise ValueError(f"unknown child {child}")
+                entries.append(e)
+            entries.sort(key=directory_entry_sort_key)
+            self.__model_object = model.Directory(entries=tuple(entries))
+        return self.__model_object
 
     def __getitem__(self, key):
         if not isinstance(key, bytes):
