@@ -91,14 +91,18 @@ COMMITTERS = [
 
 DATES = [
     TimestampWithTimezone(
-        timestamp=Timestamp(seconds=1234567891, microseconds=0,),
-        offset=120,
-        negative_utc=False,
+        timestamp=Timestamp(
+            seconds=1234567891,
+            microseconds=0,
+        ),
+        offset_bytes=b"+0200",
     ),
     TimestampWithTimezone(
-        timestamp=Timestamp(seconds=1234567892, microseconds=0,),
-        offset=120,
-        negative_utc=False,
+        timestamp=Timestamp(
+            seconds=1234567892,
+            microseconds=0,
+        ),
+        offset_bytes=b"+0200",
     ),
 ]
 
@@ -133,11 +137,40 @@ REVISIONS = [
         parents=(),
         extra_headers=((b"foo", b"bar"),),
     ),
+    Revision(
+        id=hash_to_bytes("51580d63b8dcc0ec73e74994e66896858542840a"),
+        message=b"hello",
+        date=DATES[0],
+        committer=COMMITTERS[0],
+        author=COMMITTERS[0],
+        committer_date=DATES[0],
+        type=RevisionType.GIT,
+        directory=b"\x01" * 20,
+        synthetic=False,
+        metadata=None,
+        parents=(hash_to_bytes("9b918dd063cec85c2bc63cc7f167e29f5894dcbc"),),
+        raw_manifest=(
+            b"commit 207\x00"
+            b"tree 0101010101010101010101010101010101010101\n"
+            b"parent 9B918DD063CEC85C2BC63CC7F167E29F5894DCBC"  # upper-cased
+            b"nauthor foo 1234567891 +0200\n"
+            b"committer foo 1234567891 +0200"
+            b"\n\nhello"
+        ),
+    ),
 ]
 
 EXTIDS = [
-    ExtID(extid_type="git256", extid=b"\x03" * 32, target=REVISIONS[0].swhid(),),
-    ExtID(extid_type="hg", extid=b"\x04" * 20, target=REVISIONS[1].swhid(),),
+    ExtID(
+        extid_type="git256",
+        extid=b"\x03" * 32,
+        target=REVISIONS[0].swhid(),
+    ),
+    ExtID(
+        extid_type="hg",
+        extid=b"\x04" * 20,
+        target=REVISIONS[1].swhid(),
+    ),
     ExtID(
         extid_type="hg-nodeid",
         extid=b"\x05" * 20,
@@ -151,9 +184,11 @@ RELEASES = [
         id=hash_to_bytes("8059dc4e17fcd0e51ca3bcd6b80f4577d281fd08"),
         name=b"v0.0.1",
         date=TimestampWithTimezone(
-            timestamp=Timestamp(seconds=1234567890, microseconds=0,),
-            offset=120,
-            negative_utc=False,
+            timestamp=Timestamp(
+                seconds=1234567890,
+                microseconds=0,
+            ),
+            offset_bytes=b"+0200",
         ),
         author=COMMITTERS[0],
         target_type=ObjectType.REVISION,
@@ -171,11 +206,39 @@ RELEASES = [
         message=b"bar",
         synthetic=False,
     ),
+    Release(
+        id=hash_to_bytes("1cdd1e87234b6f066d0855a3b5b567638a55d583"),
+        name=b"v0.0.1",
+        date=TimestampWithTimezone(
+            timestamp=Timestamp(
+                seconds=1234567890,
+                microseconds=0,
+            ),
+            offset_bytes=b"+0200",
+        ),
+        author=COMMITTERS[0],
+        target_type=ObjectType.REVISION,
+        target=b"\x04" * 20,
+        message=b"foo",
+        synthetic=False,
+        raw_manifest=(
+            b"tag 102\x00"
+            b"object 0404040404040404040404040404040404040404\n"
+            b"type commit\n"
+            b"tag v0.0.1\n"
+            b"tagger foo 1234567890 +200"  # missing leading 0 for timezone
+            b"\n\nfoo"
+        ),
+    ),
 ]
 
 ORIGINS = [
-    Origin(url="https://somewhere.org/den/fox",),
-    Origin(url="https://overtherainbow.org/fox/den",),
+    Origin(
+        url="https://somewhere.org/den/fox",
+    ),
+    Origin(
+        url="https://overtherainbow.org/fox/den",
+    ),
 ]
 
 ORIGIN_VISITS = [
@@ -282,10 +345,29 @@ DIRECTORIES = [
                 target=hash_to_bytes("4b825dc642cb6eb9a060e54bf8d69288fbee4904"),
             ),
             DirectoryEntry(
-                name=b"subprepo1", perms=0o160000, type="rev", target=REVISIONS[1].id,
+                name=b"subprepo1",
+                perms=0o160000,
+                type="rev",
+                target=REVISIONS[1].id,
             ),
         ),
     ),
+    Directory(
+        id=hash_to_bytes("d135a91ac82a754e7f4bdeff8d56ef06d921eb7d"),
+        entries=(
+            DirectoryEntry(
+                name=b"file1.ext",
+                perms=0o644,
+                type="file",
+                target=b"\x11" * 20,
+            ),
+        ),
+        raw_manifest=(
+            b"tree 34\x00"
+            + b"00644 file1.ext\x00"  # added two leading zeros
+            + b"\x11" * 20
+        ),
+    ),
 ]
 
 
@@ -302,13 +384,15 @@ SNAPSHOTS = [
         id=hash_to_bytes("0e7f84ede9a254f2cd55649ad5240783f557e65f"),
         branches={
             b"target/revision": SnapshotBranch(
-                target_type=TargetType.REVISION, target=REVISIONS[0].id,
+                target_type=TargetType.REVISION,
+                target=REVISIONS[0].id,
             ),
             b"target/alias": SnapshotBranch(
                 target_type=TargetType.ALIAS, target=b"target/revision"
             ),
             b"target/directory": SnapshotBranch(
-                target_type=TargetType.DIRECTORY, target=DIRECTORIES[0].id,
+                target_type=TargetType.DIRECTORY,
+                target=DIRECTORIES[0].id,
             ),
             b"target/release": SnapshotBranch(
                 target_type=TargetType.RELEASE, target=RELEASES[0].id
@@ -324,12 +408,18 @@ SNAPSHOTS = [
 
 METADATA_AUTHORITIES = [
     MetadataAuthority(
-        type=MetadataAuthorityType.FORGE, url="http://example.org/", metadata={},
+        type=MetadataAuthorityType.FORGE,
+        url="http://example.org/",
+        metadata={},
     ),
 ]
 
 METADATA_FETCHERS = [
-    MetadataFetcher(name="test-fetcher", version="1.0.0", metadata={},)
+    MetadataFetcher(
+        name="test-fetcher",
+        version="1.0.0",
+        metadata={},
+    )
 ]
 
 RAW_EXTRINSIC_METADATA = [
