@@ -36,25 +36,24 @@ def remove_id(d: Dict) -> Dict:
 class UtilityFunctionsDateOffset(unittest.TestCase):
     def setUp(self):
         self.dates = {
-            b"1448210036": {"seconds": 1448210036, "microseconds": 0,},
-            b"1448210036.002342": {"seconds": 1448210036, "microseconds": 2342,},
-            b"1448210036.12": {"seconds": 1448210036, "microseconds": 120000,},
-        }
-
-        self.offsets = {
-            0: b"+0000",
-            -630: b"-1030",
-            800: b"+1320",
+            b"1448210036": {
+                "seconds": 1448210036,
+                "microseconds": 0,
+            },
+            b"1448210036.002342": {
+                "seconds": 1448210036,
+                "microseconds": 2342,
+            },
+            b"1448210036.12": {
+                "seconds": 1448210036,
+                "microseconds": 120000,
+            },
         }
 
     def test_format_date(self):
         for date_repr, date in self.dates.items():
             self.assertEqual(git_objects.format_date(date), date_repr)
 
-    def test_format_offset(self):
-        for offset, res in self.offsets.items():
-            self.assertEqual(git_objects.format_offset(offset), res)
-
 
 content_example = {
     "status": "visible",
@@ -197,14 +196,16 @@ class DirectoryIdentifier(unittest.TestCase):
     def test_dir_identifier(self):
         self.assertEqual(Directory.from_dict(self.directory).id, self.directory["id"])
         self.assertEqual(
-            Directory.from_dict(remove_id(self.directory)).id, self.directory["id"],
+            Directory.from_dict(remove_id(self.directory)).id,
+            self.directory["id"],
         )
 
     def test_dir_identifier_entry_order(self):
         # Reverse order of entries, check the id is still the same.
         directory = {"entries": reversed(self.directory["entries"])}
         self.assertEqual(
-            Directory.from_dict(remove_id(directory)).id, self.directory["id"],
+            Directory.from_dict(remove_id(directory)).id,
+            self.directory["id"],
         )
 
     def test_dir_identifier_empty_directory(self):
@@ -291,8 +292,7 @@ dg1KdHOa34shrKDaOVzW
             },
             "date": {
                 "timestamp": {"seconds": 1437047495},
-                "offset": 0,
-                "negative_utc": False,
+                "offset_bytes": b"+0000",
             },
             "type": "tar",
             "committer": {
@@ -358,9 +358,18 @@ dg1KdHOa34shrKDaOVzW
                 "email": b"worldhello.net@gmail.com",
                 "fullname": b"Jiang Xin <worldhello.net@gmail.com>",
             },
-            "date": {"timestamp": 1428538899, "offset": 480,},
-            "committer": {"name": b"Jiang Xin", "email": b"worldhello.net@gmail.com",},
-            "committer_date": {"timestamp": 1428538899, "offset": 480,},
+            "date": {
+                "timestamp": 1428538899,
+                "offset": 480,
+            },
+            "committer": {
+                "name": b"Jiang Xin",
+                "email": b"worldhello.net@gmail.com",
+            },
+            "committer_date": {
+                "timestamp": 1428538899,
+                "offset": 480,
+            },
             "extra_headers": ((b"gpgsig", gpgsig),),
             "message": b"""Merge branch 'master' of git://github.com/alexhenrie/git-po
 
@@ -383,9 +392,18 @@ dg1KdHOa34shrKDaOVzW
                 "email": b"worldhello.net@gmail.com",
                 "fullname": b"Jiang Xin <worldhello.net@gmail.com>",
             },
-            "date": {"timestamp": 1428538899, "offset": 480,},
-            "committer": {"name": b"Jiang Xin", "email": b"worldhello.net@gmail.com",},
-            "committer_date": {"timestamp": 1428538899, "offset": 480,},
+            "date": {
+                "timestamp": 1428538899,
+                "offset": 480,
+            },
+            "committer": {
+                "name": b"Jiang Xin",
+                "email": b"worldhello.net@gmail.com",
+            },
+            "committer_date": {
+                "timestamp": 1428538899,
+                "offset": 480,
+            },
             "message": None,
             "type": "git",
             "synthetic": False,
@@ -403,9 +421,18 @@ dg1KdHOa34shrKDaOVzW
                 "email": b"worldhello.net@gmail.com",
                 "fullname": b"Jiang Xin <worldhello.net@gmail.com>",
             },
-            "date": {"timestamp": 1428538899, "offset": 480,},
-            "committer": {"name": b"Jiang Xin", "email": b"worldhello.net@gmail.com",},
-            "committer_date": {"timestamp": 1428538899, "offset": 480,},
+            "date": {
+                "timestamp": 1428538899,
+                "offset": 480,
+            },
+            "committer": {
+                "name": b"Jiang Xin",
+                "email": b"worldhello.net@gmail.com",
+            },
+            "committer_date": {
+                "timestamp": 1428538899,
+                "offset": 480,
+            },
             "message": b"",
             "type": "git",
             "synthetic": False,
@@ -415,7 +442,9 @@ dg1KdHOa34shrKDaOVzW
             "id": _x("010d34f384fa99d047cdd5e2f41e56e5c2feee45"),
             "directory": _x("85a74718d377195e1efd0843ba4f3260bad4fe07"),
             "parents": [_x("01e2d0627a9a6edb24c37db45db5ecb31e9de808")],
-            "author": {"fullname": b"Linus Torvalds <torvalds@linux-foundation.org>",},
+            "author": {
+                "fullname": b"Linus Torvalds <torvalds@linux-foundation.org>",
+            },
             "date": datetime.datetime(2015, 7, 12, 15, 10, 30, tzinfo=linus_tz),
             "committer": {
                 "fullname": b"Linus Torvalds <torvalds@linux-foundation.org>",
@@ -434,10 +463,12 @@ dg1KdHOa34shrKDaOVzW
 
     def test_revision_identifier(self):
         self.assertEqual(
-            Revision.from_dict(self.revision).id, self.revision["id"],
+            Revision.from_dict(self.revision).id,
+            self.revision["id"],
         )
         self.assertEqual(
-            Revision.from_dict(remove_id(self.revision)).id, self.revision["id"],
+            Revision.from_dict(remove_id(self.revision)).id,
+            self.revision["id"],
         )
 
     def test_revision_identifier_none_metadata(self):
@@ -537,7 +568,10 @@ o6X/3T+vm8K3bf3driRr34c=
             "target": _x("9ee1c939d1cb936b1f98e8d81aeffab57bae46ab"),
             "target_type": "revision",
             "name": b"v2.6.12",
-            "author": {"name": b"Linus Torvalds", "email": b"torvalds@g5.osdl.org",},
+            "author": {
+                "name": b"Linus Torvalds",
+                "email": b"torvalds@g5.osdl.org",
+            },
             "date": datetime.datetime(2005, 10, 27, 17, 2, 33, tzinfo=linus_tz),
             "message": None,
             "synthetic": False,
@@ -548,7 +582,10 @@ o6X/3T+vm8K3bf3driRr34c=
             "target": _x("9ee1c939d1cb936b1f98e8d81aeffab57bae46ab"),
             "target_type": "revision",
             "name": b"v2.6.12",
-            "author": {"name": b"Linus Torvalds", "email": b"torvalds@g5.osdl.org",},
+            "author": {
+                "name": b"Linus Torvalds",
+                "email": b"torvalds@g5.osdl.org",
+            },
             "date": datetime.datetime(2005, 10, 27, 17, 2, 33, tzinfo=linus_tz),
             "message": b"",
             "synthetic": False,
@@ -561,10 +598,12 @@ o6X/3T+vm8K3bf3driRr34c=
             "target_type": "revision",
             "date": {
                 "timestamp": {"seconds": 1225281976},
-                "offset": 0,
-                "negative_utc": True,
+                "offset_bytes": b"-0000",
+            },
+            "author": {
+                "name": b"Otavio Salvador",
+                "email": b"otavio@debian.org",
             },
-            "author": {"name": b"Otavio Salvador", "email": b"otavio@debian.org",},
             "synthetic": False,
             "message": b"tagging version 20081029\n\nr56558\n",
         }
@@ -576,9 +615,11 @@ o6X/3T+vm8K3bf3driRr34c=
                 "name": b"Eugene Janusov\n",
             },
             "date": {
-                "negative_utc": None,
-                "offset": 600,
-                "timestamp": {"microseconds": 0, "seconds": 1377480558,},
+                "offset_bytes": b"+1000",
+                "timestamp": {
+                    "microseconds": 0,
+                    "seconds": 1377480558,
+                },
             },
             "id": _x("5c98f559d034162de22d3ebeb95433e6f8885231"),
             "message": b"Release of v0.3.2.",
@@ -596,10 +637,12 @@ o6X/3T+vm8K3bf3driRr34c=
 
     def test_release_identifier(self):
         self.assertEqual(
-            Release.from_dict(self.release).id, self.release["id"],
+            Release.from_dict(self.release).id,
+            self.release["id"],
         )
         self.assertEqual(
-            Release.from_dict(remove_id(self.release)).id, self.release["id"],
+            Release.from_dict(remove_id(self.release)).id,
+            self.release["id"],
         )
 
     def test_release_identifier_no_author(self):
@@ -650,7 +693,10 @@ snapshot_example = {
             "target": _x("fe95a46679d128ff167b7c55df5d02356c5a1ae1"),
             "target_type": "content",
         },
-        b"alias": {"target": b"revision", "target_type": "alias",},
+        b"alias": {
+            "target": b"revision",
+            "target_type": "alias",
+        },
         b"revision": {
             "target": _x("aafb16d69fd30ff58afdd69036a26047f3aebdc6"),
             "target_type": "revision",
@@ -679,19 +725,27 @@ class SnapshotIdentifier(unittest.TestCase):
 
         self.dangling_branch = {
             "id": _x("c84502e821eb21ed84e9fd3ec40973abc8b32353"),
-            "branches": {b"HEAD": None,},
+            "branches": {
+                b"HEAD": None,
+            },
         }
 
         self.unresolved = {
             "id": _x("84b4548ea486e4b0a7933fa541ff1503a0afe1e0"),
-            "branches": {b"foo": {"target": b"bar", "target_type": "alias",},},
+            "branches": {
+                b"foo": {
+                    "target": b"bar",
+                    "target_type": "alias",
+                },
+            },
         }
 
         self.all_types = snapshot_example
 
     def test_empty_snapshot(self):
         self.assertEqual(
-            Snapshot.from_dict(remove_id(self.empty)).id, self.empty["id"],
+            Snapshot.from_dict(remove_id(self.empty)).id,
+            self.empty["id"],
         )
 
     def test_dangling_branch(self):
@@ -701,12 +755,19 @@ class SnapshotIdentifier(unittest.TestCase):
         )
 
     def test_unresolved(self):
+        self.assertEqual(
+            Snapshot.from_dict(remove_id(self.unresolved)).id, self.unresolved["id"]
+        )
+
+    def test_git_object_unresolved(self):
         with self.assertRaisesRegex(ValueError, "b'foo' -> b'bar'"):
-            Snapshot.from_dict(remove_id(self.unresolved))
+            git_objects.snapshot_git_object(self.unresolved)
+        git_objects.snapshot_git_object(self.unresolved, ignore_unresolved=True)
 
     def test_all_types(self):
         self.assertEqual(
-            Snapshot.from_dict(remove_id(self.all_types)).id, self.all_types["id"],
+            Snapshot.from_dict(remove_id(self.all_types)).id,
+            self.all_types["id"],
         )
 
 
@@ -847,7 +908,13 @@ class RawExtrinsicMetadataIdentifier(unittest.TestCase):
         metadata = {
             **self.minimal,
             "discovery_date": datetime.datetime(
-                2021, 1, 25, 12, 27, 51, tzinfo=utc_plus_one,
+                2021,
+                1,
+                25,
+                12,
+                27,
+                51,
+                tzinfo=utc_plus_one,
             ),
         }
 
@@ -874,7 +941,14 @@ class RawExtrinsicMetadataIdentifier(unittest.TestCase):
         metadata = {
             **self.minimal,
             "discovery_date": datetime.datetime(
-                2021, 1, 25, 11, 27, 51, 123456, tzinfo=datetime.timezone.utc,
+                2021,
+                1,
+                25,
+                11,
+                27,
+                51,
+                123456,
+                tzinfo=datetime.timezone.utc,
             ),
         }
 
@@ -902,7 +976,14 @@ class RawExtrinsicMetadataIdentifier(unittest.TestCase):
         metadata = {
             **self.minimal,
             "discovery_date": datetime.datetime(
-                2021, 1, 25, 11, 27, 50, 1_000_000 - 42, tzinfo=tz,
+                2021,
+                1,
+                25,
+                11,
+                27,
+                50,
+                1_000_000 - 42,
+                tzinfo=tz,
             ),
         }
 
@@ -927,7 +1008,13 @@ class RawExtrinsicMetadataIdentifier(unittest.TestCase):
         metadata = {
             **self.minimal,
             "discovery_date": datetime.datetime(
-                1960, 1, 25, 11, 27, 51, tzinfo=datetime.timezone.utc,
+                1960,
+                1,
+                25,
+                11,
+                27,
+                51,
+                tzinfo=datetime.timezone.utc,
             ),
         }
 
@@ -961,7 +1048,13 @@ class RawExtrinsicMetadataIdentifier(unittest.TestCase):
         metadata = {
             **self.minimal,
             "discovery_date": datetime.datetime(
-                1970, 1, 1, 0, 0, 0, tzinfo=datetime.timezone.utc,
+                1970,
+                1,
+                1,
+                0,
+                0,
+                0,
+                tzinfo=datetime.timezone.utc,
             ),
         }
 
@@ -995,7 +1088,14 @@ class RawExtrinsicMetadataIdentifier(unittest.TestCase):
         metadata = {
             **self.minimal,
             "discovery_date": datetime.datetime(
-                1969, 12, 31, 23, 59, 59, 1, tzinfo=datetime.timezone.utc,
+                1969,
+                12,
+                31,
+                23,
+                59,
+                59,
+                1,
+                tzinfo=datetime.timezone.utc,
             ),
         }
 
@@ -1039,13 +1139,66 @@ class OriginIdentifier(unittest.TestCase):
         )
 
 
+# Format: [
+#   (
+#       input1,
+#       expected_output1,
+#   ),
+#   (
+#       input2,
+#       expected_output2,
+#   ),
+#   ...
+# ]
 TS_DICTS = [
+    # with current input dict format (offset_bytes)
+    (
+        {"timestamp": 12345, "offset_bytes": b"+0000"},
+        {
+            "timestamp": {"seconds": 12345, "microseconds": 0},
+            "offset_bytes": b"+0000",
+        },
+    ),
+    (
+        {"timestamp": 12345, "offset_bytes": b"-0000"},
+        {
+            "timestamp": {"seconds": 12345, "microseconds": 0},
+            "offset_bytes": b"-0000",
+        },
+    ),
+    (
+        {"timestamp": 12345, "offset_bytes": b"+0200"},
+        {
+            "timestamp": {"seconds": 12345, "microseconds": 0},
+            "offset_bytes": b"+0200",
+        },
+    ),
+    (
+        {"timestamp": 12345, "offset_bytes": b"-0200"},
+        {
+            "timestamp": {"seconds": 12345, "microseconds": 0},
+            "offset_bytes": b"-0200",
+        },
+    ),
+    (
+        {"timestamp": 12345, "offset_bytes": b"--700"},
+        {
+            "timestamp": {"seconds": 12345, "microseconds": 0},
+            "offset_bytes": b"--700",
+        },
+    ),
+    (
+        {"timestamp": 12345, "offset_bytes": b"1234567"},
+        {
+            "timestamp": {"seconds": 12345, "microseconds": 0},
+            "offset_bytes": b"1234567",
+        },
+    ),
+    # with old-style input dicts (numeric offset + optional negative_utc):
     (
         {"timestamp": 12345, "offset": 0},
         {
             "timestamp": {"seconds": 12345, "microseconds": 0},
-            "offset": 0,
-            "negative_utc": False,
             "offset_bytes": b"+0000",
         },
     ),
@@ -1053,8 +1206,6 @@ TS_DICTS = [
         {"timestamp": 12345, "offset": 0, "negative_utc": False},
         {
             "timestamp": {"seconds": 12345, "microseconds": 0},
-            "offset": 0,
-            "negative_utc": False,
             "offset_bytes": b"+0000",
         },
     ),
@@ -1062,8 +1213,6 @@ TS_DICTS = [
         {"timestamp": 12345, "offset": 0, "negative_utc": False},
         {
             "timestamp": {"seconds": 12345, "microseconds": 0},
-            "offset": 0,
-            "negative_utc": False,
             "offset_bytes": b"+0000",
         },
     ),
@@ -1071,8 +1220,6 @@ TS_DICTS = [
         {"timestamp": 12345, "offset": 0, "negative_utc": None},
         {
             "timestamp": {"seconds": 12345, "microseconds": 0},
-            "offset": 0,
-            "negative_utc": False,
             "offset_bytes": b"+0000",
         },
     ),
@@ -1080,8 +1227,6 @@ TS_DICTS = [
         {"timestamp": {"seconds": 12345}, "offset": 0, "negative_utc": None},
         {
             "timestamp": {"seconds": 12345, "microseconds": 0},
-            "offset": 0,
-            "negative_utc": False,
             "offset_bytes": b"+0000",
         },
     ),
@@ -1093,8 +1238,6 @@ TS_DICTS = [
         },
         {
             "timestamp": {"seconds": 12345, "microseconds": 0},
-            "offset": 0,
-            "negative_utc": False,
             "offset_bytes": b"+0000",
         },
     ),
@@ -1106,8 +1249,6 @@ TS_DICTS = [
         },
         {
             "timestamp": {"seconds": 12345, "microseconds": 100},
-            "offset": 0,
-            "negative_utc": False,
             "offset_bytes": b"+0000",
         },
     ),
@@ -1115,8 +1256,6 @@ TS_DICTS = [
         {"timestamp": 12345, "offset": 0, "negative_utc": True},
         {
             "timestamp": {"seconds": 12345, "microseconds": 0},
-            "offset": 0,
-            "negative_utc": True,
             "offset_bytes": b"-0000",
         },
     ),
@@ -1124,8 +1263,6 @@ TS_DICTS = [
         {"timestamp": 12345, "offset": 0, "negative_utc": None},
         {
             "timestamp": {"seconds": 12345, "microseconds": 0},
-            "offset": 0,
-            "negative_utc": False,
             "offset_bytes": b"+0000",
         },
     ),
@@ -1182,8 +1319,6 @@ def test_normalize_timestamp_datetime(
     date = date.astimezone(tz).replace(microsecond=microsecond)
     assert TimestampWithTimezone.from_dict(date).to_dict() == {
         "timestamp": {"seconds": seconds, "microseconds": microsecond},
-        "offset": offset,
-        "negative_utc": False,
         "offset_bytes": offset_bytes,
     }
 
